
from django.db import models
from django.utils.translation import ugettext_lazy as _

from ordered_model.models import OrderedModel


class SliderImage(OrderedModel):

    title = models.CharField(_('Title'), blank=True, max_length=255)

    file = models.ImageField(
        _("File"), upload_to='slider_images', max_length=255)

    url = models.URLField(_('Url'), max_length=255, blank=True)

    def __str__(self):
        return self.title

    class Meta:
        ordering = ('order', 'id', )
        verbose_name = _('Slider image')
        verbose_name_plural = _('Slider images')



# Generated by Django 2.2.1 on 2019-08-31 18:06

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='SliderImage',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('order', models.PositiveIntegerField(db_index=True, editable=False, verbose_name='order')),
                ('title', models.CharField(blank=True, max_length=255, verbose_name='Title')),
                ('file', models.ImageField(max_length=255, upload_to='slider_images', verbose_name='File')),
                ('url', models.URLField(blank=True, max_length=255, verbose_name='Url')),
            ],
            options={
                'verbose_name': 'Slider image',
                'verbose_name_plural': 'Slider images',
                'ordering': ('order', 'id'),
            },
        ),
    ]




from django.contrib import admin

from ordered_model.admin import OrderedModelAdmin

from slider.models import SliderImage


@admin.register(SliderImage)
class SliderImageAdmin(OrderedModelAdmin):

    list_display = ['id', 'title', 'file', 'url']
    fields = ['title', 'file', 'url']
    list_display_links = ['id', 'title']




from django import template
from django.conf import settings

from slider.models import SliderImage


register = template.Library()


@register.inclusion_tag('slider.html')
def render_slider():
    return {'slider_photos': SliderImage.objects.all()}


@register.inclusion_tag('slideshow.html')
def render_slideshow(images, preview_size=None):
    return {
        'MEDIA_URL': settings.MEDIA_URL,
        'images': images,
        'preview_size': preview_size
    }


@register.inclusion_tag('slideshow_js.html', name='slideshow_js')
def render_slideshow_js(group_name='slideshow'):
    return {
        'STATIC_URL': settings.STATIC_URL,
        'group_name': group_name
    }
